@@ -19,7 +19,18 @@ from pulp_rpm.app.models import (
     Package,
     RpmRepository,
 )
-from pulp_rpm.app.tasks.synchronizing import RpmContentSaver
+from pulp_rpm.app.tasks.synchronizing import (
+    RpmContentSaver,
+    RpmQueryExistingContents,
+)
+
+from pulpcore.plugin.stages import (
+    ArtifactSaver,
+    RemoteArtifactSaver,
+    ResolveContentFutures,
+    Stage,
+    QueryExistingArtifacts,
+)
 
 from . import pulp2_models
 
@@ -42,14 +53,7 @@ from .repository import (
     RpmImporter,
 )
 
-from pulpcore.plugin.stages import (
-    ArtifactSaver,
-    RemoteArtifactSaver,
-    ResolveContentFutures,
-    Stage,
-    QueryExistingArtifacts,
-    QueryExistingContents,
-)
+from .utils import exclude_unsupported_metadata
 
 from . import package_utils
 
@@ -127,6 +131,9 @@ class RpmMigrator(Pulp2to3PluginMigrator):
     multi_artifact_types = {
         'distribution': Pulp2Distribution
     }
+    premigrate_hook = {
+        'yum_repo_metadata_file': exclude_unsupported_metadata,
+    }
 
     @classmethod
     def migrate_content_to_pulp3(cls, skip_corrupted=False):
@@ -164,7 +171,7 @@ class RpmDeclarativeContentMigration(DeclarativeContentMigration):
             self.first_stage,
             QueryExistingArtifacts(),
             ArtifactSaver(),
-            QueryExistingContents(),
+            RpmQueryExistingContents(),
             RpmContentSaver(),
             RemoteArtifactSaver(),
             UpdateLCEs(),
